Struct starry::GetCommand
source · pub struct GetCommand {
pub name: String,
}Expand description
get a property, eg starry get github-api-token
Fields
name: StringTrait Implementations
sourceimpl Debug for GetCommand
impl Debug for GetCommand
sourceimpl FromArgs for GetCommand
impl FromArgs for GetCommand
sourcefn from_args(__cmd_name: &[&str], __args: &[&str]) -> Result<Self, EarlyExit>
fn from_args(__cmd_name: &[&str], __args: &[&str]) -> Result<Self, EarlyExit>
Construct the type from an input set of arguments. Read more
sourcefn redact_arg_values(
__cmd_name: &[&str],
__args: &[&str]
) -> Result<Vec<String>, EarlyExit>
fn redact_arg_values( __cmd_name: &[&str], __args: &[&str] ) -> Result<Vec<String>, EarlyExit>
Get a String with just the argument names, e.g., options, flags, subcommands, etc, but
without the values of the options and arguments. This can be useful as a means to capture
anonymous usage statistics without revealing the content entered by the end user. Read more
sourceimpl PartialEq for GetCommand
impl PartialEq for GetCommand
sourcefn eq(&self, other: &GetCommand) -> bool
fn eq(&self, other: &GetCommand) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl SubCommand for GetCommand
impl SubCommand for GetCommand
sourceconst COMMAND: &'static CommandInfo = _
const COMMAND: &'static CommandInfo = _
Information about the subcommand.
impl StructuralPartialEq for GetCommand